==> querydsl-parser-0.2-sources.jar: foundation/jpa/querydsl/StateLPar11.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateLPar11 extends StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> {

// NoStack:
// Stack:
    public StateLPar11(foundation.jpa.querydsl.QueryFactory factory, foundation.rpg.common.symbols.LPar node, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        
        return this.visitCommaSeparatedListOfExpression(foundation.rpg.common.rules.CommaSeparated.Rules.is()).visitRPar(symbol);
    }


// Shift:
    @Override
    public State visitCommaSeparatedListOfExpression(java.util.List<com.querydsl.core.types.Expression> symbol) {
        return new StateCommaSeparatedListOfExpression3(getFactory(), symbol, this);
    }

    @Override
    public State visitCommaSeparatedNonEmptyListOfExpression(java.util.List<com.querydsl.core.types.Expression> symbol) {
        return new StateCommaSeparatedNonEmptyListOfExpression1(getFactory(), symbol, this);
    }

    @Override
    public State visitExpression(com.querydsl.core.types.Expression symbol) {
        return new StateExpression9(getFactory(), symbol, this);
    }

    @Override
    public State visitDouble(java.lang.Double symbol) {
        return new StateDouble9(getFactory(), symbol, this);
    }

    @Override
    public State visitInteger(java.lang.Integer symbol) {
        return new StateInteger9(getFactory(), symbol, this);
    }

    @Override
    public State visitString(java.lang.String symbol) {
        return new StateString9(getFactory(), symbol, this);
    }

    @Override
    public State visitObject(java.lang.Object symbol) {
        return new StateObject9(getFactory(), symbol, this);
    }

    @Override
    public State visitIdentifier(foundation.rpg.common.symbols.Identifier symbol) {
        return new StateIdentifier10(getFactory(), symbol, this);
    }


// Accept:
    @Override
    public List<Object> stack() {
        StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return Arrays.asList(stack2.getNode(), stack1.getNode(), this.getNode());
    }

}

==> querydsl-parser-0.7-sources.jar: foundation/jpa/querydsl/StateLPar11.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateLPar11 extends StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> {

// NoStack:
// Stack:
    public StateLPar11(foundation.jpa.querydsl.QueryFactory factory, foundation.rpg.common.symbols.LPar node, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        
        return this.visitCommaSeparatedListOfObject(foundation.rpg.common.rules.CommaSeparated.Rules.is()).visitRPar(symbol);
    }


// Shift:
    @Override
    public State visitCommaSeparatedListOfObject(java.util.List<java.lang.Object> symbol) {
        return new StateCommaSeparatedListOfObject1(getFactory(), symbol, this);
    }

    @Override
    public State visitCommaSeparatedNonEmptyListOfObject(java.util.List<java.lang.Object> symbol) {
        return new StateCommaSeparatedNonEmptyListOfObject1(getFactory(), symbol, this);
    }

    @Override
    public State visitObject(java.lang.Object symbol) {
        return new StateObject18(getFactory(), symbol, this);
    }

    @Override
    public State visitIdentifier(foundation.rpg.common.symbols.Identifier symbol) {
        return new StateIdentifier11(getFactory(), symbol, this);
    }


// Accept:
    @Override
    public List<Object> stack() {
        StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack1 = this.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack2 = stack1.getPrev();
		State stack3 = stack2.getPrev();
        return Arrays.asList(stack2.getNode(), stack1.getNode(), this.getNode());
    }

}
